#' @importFrom magrittr %>%
#' @export
magrittr::`%>%`

#' @importFrom rxode2 rxode2
#' @export
rxode2::rxode2

#' @importFrom rxode2 rxUiDeparse
#' @export
rxode2::rxUiDeparse

#' @importFrom rxode2 as.rxUi
#' @export
rxode2::as.rxUi

#' @importFrom rxode2 rxode
#' @export
rxode2::rxode

#' @importFrom rxode2 RxODE
#' @export
rxode2::RxODE

#' @importFrom rxode2 ini
#' @export
rxode2::ini

#' @importFrom rxode2 model
#' @export
rxode2::model

#' @importFrom rxode2 lotri
#' @export
rxode2::lotri


#' @importFrom rxode2 logit
#' @export
rxode2::logit

#' @importFrom rxode2 expit
#' @export
rxode2::expit

#' @importFrom rxode2 probit
#' @export
rxode2::probit

#' @importFrom rxode2 probitInv
#' @export
rxode2::probitInv

#' @importFrom rxode2 rxSolve
#' @export
rxode2::rxSolve

#' @importFrom rxode2 rxClean
#' @export
rxode2::rxClean

#' @importFrom rxode2 rxCat
#' @export
rxode2::rxCat

#' @importFrom nlme nlme
#' @export
nlme::nlme

#' @importFrom nlme ACF
#' @export
nlme::ACF

#' @importFrom nlme VarCorr
#' @export
nlme::VarCorr

#' @importFrom nlme getVarCov
#' @export
nlme::getVarCov


#' @importFrom nlme augPred
#' @export
nlme::augPred

#' @importFrom nlme fixef
#' @export
nlme::fixef

#' @importFrom nlme fixed.effects
#' @export
nlme::fixed.effects

#' @importFrom nlme ranef
#' @export
nlme::ranef

#' @importFrom nlme random.effects
#' @export
nlme::random.effects

#' @importFrom rxode2 eventTable
#' @export
rxode2::eventTable

#' @importFrom rxode2 add.dosing
#' @export
rxode2::add.dosing

#' @importFrom rxode2 add.sampling
#' @export
rxode2::add.sampling

#' @importFrom nlme pdDiag
#' @export
nlme::pdDiag

#' @importFrom nlme pdSymm
#' @export
nlme::pdSymm

#' @importFrom nlme pdLogChol
#' @export
nlme::pdLogChol

#' @importFrom nlme pdIdent
#' @export
nlme::pdIdent

#' @importFrom nlme pdCompSymm
#' @export
nlme::pdCompSymm

#' @importFrom nlme pdBlocked
#' @export
nlme::pdBlocked

#' @importFrom nlme pdNatural
#' @export
nlme::pdNatural

#' @importFrom nlme pdConstruct
#' @export
nlme::pdConstruct

#' @importFrom nlme pdFactor
#' @export
nlme::pdFactor

#' @importFrom nlme pdMat
#' @export
nlme::pdMat

#' @importFrom nlme pdMatrix
#' @export
nlme::pdMatrix

#' @importFrom nlme reStruct
#' @export
nlme::reStruct

#' @importFrom nlme varWeights
#' @export
nlme::varWeights

#' @importFrom nlme varPower
#' @export
nlme::varPower

#' @importFrom nlme varFixed
#' @export
nlme::varFixed

#' @importFrom nlme varFunc
#' @export
nlme::varFunc

#' @importFrom nlme varExp
#' @export
nlme::varExp

#' @importFrom nlme varConstPower
#' @export
nlme::varConstPower

#' @importFrom nlme varIdent
#' @export
nlme::varIdent

#' @importFrom nlme varComb
#' @export
nlme::varComb

#' @importFrom nlme groupedData
#' @export
nlme::groupedData

#' @importFrom nlme getData
#' @export
nlme::getData

#' @importFrom rxode2 et
#' @export
rxode2::et

#' @importFrom rxode2 rxParams
#' @export
rxode2::rxParams

#' @importFrom rxode2 rxParam
#' @export
rxode2::rxParam


#' @importFrom rxode2 et
#' @export
rxode2::et

#' @importFrom rxode2 geom_cens
#' @export
rxode2::geom_cens

#' @importFrom rxode2 geom_amt
#' @export
rxode2::geom_amt


#' @importFrom rxode2 stat_cens
#' @export
rxode2::stat_cens

#' @importFrom rxode2 stat_amt
#' @export
rxode2::stat_amt

#' @importFrom rxode2 rxControl
#' @export
rxode2::rxControl

#' @importFrom rxode2 rxModelVars
#' @export
rxode2::rxModelVars

#' @importFrom rxode2 rxLhs
#' @export
rxode2::rxLhs

#' @importFrom rxode2 rxState
#' @export
rxode2::rxState

#' @importFrom rxode2 rxInit
#' @export
rxode2::rxInit

#' @importFrom rxode2 rxParams
#' @export
rxode2::rxParams

#' @importFrom rxode2 rxModelVarsS3
#' @export
rxode2::rxModelVarsS3
